#!/usr/bin/env python
import sys
from setuptools import setup, Extension


def readme():
    with open("README.md", "r") as f:
        return f.read()


pkg_metadata = dict(
    name             = "amplitude",
    version          = "0.2.0",
    description      = "solving the factored transport equation with the Lax-Friedrich sweeping method",
    long_description = readme(),
    long_description_content_type = "text/markdown",
    url              = "",
    author           = "Kevin Ganster",
    author_email     = "kevinganster@gmail.com",
    license          = "MIT",
    keywords         = "Lax-Friedrich, Lax-Friedrich sweeping, sweeping method, transport equation, factored transport equation",
    install_requires = ["numpy >= 1.7"],
    # "Development Status :: 4 - Beta",
    classifiers      = [ "License :: OSI Approved :: MIT License",
                         "Operating System :: OS Independent",
                         "Topic :: Scientific/Engineering :: Mathematics",
                         "Programming Language :: C++",
                         "Programming Language :: Python :: 3.7"],
    packages = ["amplitude"]
)


def parse_setuppy_commands():
    """Check the commands and respond appropriately.
    Return a boolean value for whether or not to run the build or not.
    
    Inspired from SciPy's setup.py : https://github.com/scipy/scipy/blob/master/setup.py
    """
    args = sys.argv[1:]

    if not args:
        # User forgot to give an argument probably, let setuptools handle that.
        return True

    info_commands = ['--help-commands', '--name', '--version', '-V',
                     '--fullname', '--author', '--author-email',
                     '--maintainer', '--maintainer-email', '--url',
                     '--license', '--description', '--long-description',
                     '--platforms', '--classifiers', '--keywords',
                     '--provides', '--requires', '--obsoletes',
                     'egg_info', 'install_egg_info', 'rotate']

    for command in info_commands:
        if command in args:
            return False

    good_commands = ('develop', 'sdist', 'build', 'build_ext', 'build_py',
                     'build_clib', 'build_scripts', 'bdist_wheel', 'bdist_rpm',
                     'bdist_wininst', 'bdist_msi', 'bdist_mpkg',
                     'build_sphinx')

    for command in good_commands:
        if command in args:
            return True

    # The following commands are supported, but we need to show more useful messages to the user
    if "install" in args:
        print("Note: if you need reliable uninstall behavior, you should install with pip instead of using `setup.py install`:"
              "  - `pip install .`       (from a git repo or downloaded source release)")
        return True

    return False


if __name__ == "__main__":
    if "--force" in sys.argv:
        run_build = True
        sys.argv.remove("--force")
    else:
        # Raise errors for unsupported commands, improve help output, etc.
        run_build = parse_setuppy_commands()

    if run_build:
        # non-build actions should not include the extension module,
        # for example when pip is used to install this when NumPy is not yet present in the system.
        import numpy as np

        pkg_metadata['ext_modules'] = [
            Extension(
                "amplitude.camplitude",
                sources=[   "amplitude/camplitude.cpp",
                            "amplitude/sweeping.cpp",
                            "amplitude/hamiltonians.cpp"],
                include_dirs=[  "amplitude",
                                np.get_include()],
                language="c++",
                extra_compile_args=["-std=c++11"]
            )
        ]

    setup(**pkg_metadata)

 
