import os
import matplotlib.pyplot as plt


def init(plt_init=True) -> bool:
    if plt_init:
        plt.rcParams.update({
            'figure.dpi': 150,

#            'text.usetex': True,
            'axes.labelsize': 16,
            'xtick.labelsize': 14, # size of axis numbers
            'ytick.labelsize': 14,
        
            'savefig.pad_inches': 0.01,
            'savefig.bbox': "tight",
            'savefig.orientation': "landscape"
        })

def create_figure(invert_yaxis=True, equal=True, **figure_kwargs) -> plt.Figure:
    fig = plt.figure(dpi=150, **figure_kwargs)
    ax = plt.gca()
    if invert_yaxis:
        ax.invert_yaxis()
    if equal:
        ax.set_aspect("equal")
    return fig, ax

def subplot(*args, invert_yaxis=True, equal=True, **kwargs):
    ax = plt.subplot(*args, **kwargs)
    if invert_yaxis:
        ax.invert_yaxis()
    if equal:
        ax.set_aspect("equal")
    return ax

def save_figure(path, fig) -> None:
    fig.savefig(path, orientation="landscape", bbox_inches="tight", pad_inches=0.01)
    plt.close(fig)

def cutoff_str(L_s, R_s, L_t, R_t):
    return f"""$L_s = {L_s}$, $R_s = {R_s}$,\\\\
$L_t = {L_t}$, $R_t = {R_t}$."""
